==> node-espree_7.3.1~dfsg1.orig.tar.xz: espree-7.3.1/tests/fixtures/ecma-version/9/regexp-s-flag/s-flag.result.js <==
const conditionalRegex = require("../../../../lib/conditional-regex-value");

module.exports = {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 1,
            "column": 4
        }
    },
    "range": [
        0,
        4
    ],
    "body": [
        {
            "type": "ExpressionStatement",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 4
                }
            },
            "range": [
                0,
                4
            ],
            "expression": conditionalRegex({
                "type": "Literal",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 0
                    },
                    "end": {
                        "line": 1,
                        "column": 4
                    }
                },
                "range": [
                    0,
                    4
                ],
                "raw": "/./s",
                "regex": {
                    "pattern": ".",
                    "flags": "s"
                }
            })
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "RegularExpression",
            "value": "/./s",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 4
                }
            },
            "range": [
                0,
                4
            ],
            "regex": {
                "flags": "s",
                "pattern": "."
            }
        }
    ]
};

==> node-espree_9.4.1~dfsg.orig.tar.xz: espree-9.4.1/tests/fixtures/ecma-version/9/regexp-s-flag/s-flag.result.js <==
import conditionalRegex from "../../../../lib/conditional-regex-value.js";

export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 1,
            "column": 4
        }
    },
    "range": [
        0,
        4
    ],
    "body": [
        {
            "type": "ExpressionStatement",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 4
                }
            },
            "range": [
                0,
                4
            ],
            "expression": conditionalRegex({
                "type": "Literal",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 0
                    },
                    "end": {
                        "line": 1,
                        "column": 4
                    }
                },
                "range": [
                    0,
                    4
                ],
                "raw": "/./s",
                "regex": {
                    "pattern": ".",
                    "flags": "s"
                }
            })
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "RegularExpression",
            "value": "/./s",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 4
                }
            },
            "range": [
                0,
                4
            ],
            "regex": {
                "flags": "s",
                "pattern": "."
            }
        }
    ]
};
